==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/tr.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Gizlilik",
    "-" : "-",
    "Add external admin" : "Dış yönetici ekle",
    "Your files are not protected by encryption." : "Dosyalarınız şifreleme ile korunmuyor.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Dosyalarınız {linkopen}sunucu tarafı şifrelemesi ↗{linkclose} ile korunuyor.",
    "This server is protected with full-disk-encryption." : "Bu sunucu tam disk şifrelemesi ile korunuyor.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Dosyalarınız {linkopen}sunucu tarafı şifrelemesi ↗{linkclose} ile korunuyor. Ek olarak bu sunucu tam disk şifrelemesi ile korunuyor.",
    "This server is using full-disk-encryption." : "Bu sunucu tam disk şifrelemesi ile korunuyor.",
    "Your data is located in: " : "Verileriniz şurada tutuluyor:",
    "The admin hasn't selected the location of the server yet." : "Yönetici henüz sunucunun konumunu seçmemiş.",
    "Please select a country" : "Lütfen bir ülke seçin",
    "You don't have any shares with individual users." : "Diğer kullanıcılar ile herhangi bir şey paylaşmıyorsunuz.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "Birleşik Arap Emirlikleri",
    "Afghanistan" : "Afganistan",
    "Albania" : "Arnavutluk",
    "Armenia" : "Ermenistan",
    "Angola" : "Angola",
    "Argentina" : "Arjantin",
    "Austria" : "Avusturya",
    "Australia" : "Avustralya",
    "Azerbaijan" : "Azerbaycan",
    "Bosnia and Herzegowina" : "Bosna ve Hersek",
    "Bangladesh" : "Bangladeş",
    "Belgium" : "Belçika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaristan",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivya",
    "Brazil" : "Brezilya",
    "Bahamas" : "Bahamalar",
    "Bhutan" : "Butan",
    "Botswana" : "Botswana",
    "Belarus" : "Beyaz Rusya",
    "Belize" : "Beliz",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Kongo Demokratik Cumhuriyeti",
    "Central African Republic" : "Orta Afrika Cumhuriyeti",
    "Congo" : "Kongo",
    "Switzerland" : "İsviçre",
    "Cote d'Ivoire" : "Fildişi Sahili",
    "Chile" : "Şili",
    "Cameroon" : "Kamerun",
    "China" : "Çin",
    "Colombia" : "Kolombiya",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Küba",
    "Cyprus" : "Kıbrıs",
    "Czech" : "Çekya",
    "Germany" : "Almanya",
    "Djibouti" : "Cibuti",
    "Denmark" : "Danimarka",
    "Dominican Republic" : "Dominik Cumhuriyeti",
    "Algeria" : "Cezayir",
    "Ecuador" : "Ekvator",
    "Estonia" : "Estonya",
    "Egypt" : "Mısır",
    "West Sahara" : "Batı Sahra",
    "Eritrea" : "Eritre",
    "Spain" : "İspanya",
    "Ethiopia" : "Etiyopya",
    "Finland" : "Finlandiya",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falkland Adaları",
    "France" : "Fransa",
    "Gabon" : "Gabon",
    "United Kingdom" : "Birleşik Kırallık",
    "Georgia" : "Gürcistan",
    "Ghana" : "Gana",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Gine",
    "Equatorial Guinea" : "Ekvator Ginesi",
    "Greece" : "Yunanistan",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Gine-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Hırvatistan",
    "Haiti" : "Haiti",
    "Hungary" : "Macaristan",
    "Indonesia" : "Endonezya",
    "Ireland" : "İrlanda",
    "Israel" : "İsrail",
    "India" : "Hindistan",
    "Iraq" : "Irak",
    "Iran" : "İran",
    "Iceland" : "İzlanda",
    "Italy" : "İtalya",
    "Jamaica" : "Jamaika",
    "Jordan" : "Ürdün",
    "Japan" : "Japonya",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kırgızistan",
    "Cambodia" : "Kamboçya",
    "North Korea" : "Kuzey Kore",
    "South Korea" : "Güney Kore",
    "Kuwait" : "Kuveyt",
    "Kazakhstan" : "Kazakistan",
    "Laos" : "Laos",
    "Lebanon" : "Lübnan",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberya",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litvanya",
    "Luxembourg" : "Lüksemburg",
    "Latvia" : "Letonya",
    "Libya" : "Libra",
    "Morocco" : "Fas",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Macedonia" : "Makedonya",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Moğolistan",
    "Mauritania" : "Moritanya",
    "Malawi" : "Malawi",
    "Mexico" : "Meksika",
    "Malaysia" : "Malezya",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibya",
    "New Caledonia" : "Yeni Kaledonya",
    "Niger" : "Nijer",
    "Nigeria" : "Nijerya",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollanda",
    "Norway" : "Norveç",
    "Nepal" : "Nepal",
    "New Zealand" : "Yeni Zelanda",
    "Oman" : "Umman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Yeni Gine",
    "Philippines" : "Filipinler",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonya",
    "Puerto Rico" : "Porto Riko",
    "Portugal" : "Portekiz",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Romania" : "Romanya",
    "Serbia" : "Sırbistan",
    "Russia" : "Rusya",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Suudi Arabistan",
    "Solomon Islands" : "Solomon Adaları",
    "Sudan" : "Sudan",
    "Sweden" : "İsveç",
    "Singapore" : "Singapur",
    "Slovenia" : "Slovenya",
    "Slovakia" : "Slovakya",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somali",
    "Suriname" : "Surinam",
    "South Sudan" : "Güney Sudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Suriye",
    "Swaziland" : "Swaziland",
    "Chad" : "Çad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarktika Bölgesi",
    "Togo" : "Togo",
    "Thailand" : "Tayland",
    "Tajikistan" : "Tacikistan",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Türkmenistan",
    "Tunisia" : "Tunus",
    "Turkey" : "Türkiye",
    "Trinidad and Tobago" : "Trinidad ve Tobago",
    "Taiwan" : "Tayvan",
    "Tanzania" : "Tanzanya",
    "Ukraine" : "Ukrayna",
    "Uganda" : "Uganda",
    "United States" : "Birleşik Devletler",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Özbekistan",
    "Venezuela" : "Venezüela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "Güney Afrika",
    "Zambia" : "Zambiya",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Nextcloud hesabınız",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Verileriniz sizin kim olduğunuzu gösterir ve kolayca kötüye kullanılabilir. Nextcloud olarak verilerinize ne olacağına karar verme hakkınız olduğuna inanıyoruz. Nextcloud, Kullanıcı Verileri Manifestosu'nda belirtildiği şekilde haklarınızı korur!",
    "User Data Manifesto 2.0" : "Kullanıcı Verileri Manifestosu 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "İnternet çağında kişilerin kendi verilerini kontrol etmesi için temel hak tanımları",
    "Control" : "Kontrol",
    "over user data access" : "kullanıcının verilerine erişebilmesi",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Bir kullanıcı tarafından açıkça ve isteyerek yüklenen veriler, tam olarak kullanıcının kontrolü altında olmalıdır. Kullanıcılar, verilerine doğrudan kimin erişebileceğine ve bu erişim için hangi izin ve lisansların kullanılacağına karar verebilmelidir.",
    "Knowledge" : "Bilgi",
    "of how the data is stored" : "verilerin nasıl saklandığını bilme",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Veriler belirli bir hizmet sağlayıcıya yüklendiğinde, kullanıcılara bu hizmet sağlayıcısının verileri nerede ve ne kadar süreyle sakladığı, çalıştığı bölge ve bu bölgede geçerli olan yasalar hakkında bilgi verilmelidir.",
    "Freedom" : "Özgürlük",
    "to choose a platform" : "istediğiniz platformu seçebilme",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Kullanıcılar, herhangi bir hizmet sağlayıcı engellemesine maruz kalmadan, istedikleri zaman verilerini alabilmelidir. Bunu garanti etmek için biçim ve yönergeler hakkında açık standartlar bulunmalıdır.",
    "Learn more ↗" : "Ayrıntılı bilgi alın ↗",
    "Where is your data?" : "Verileriniz nerede tutuluyor?",
    "Who has access to your data?" : "Verilerinize kimler erişebiliyor?",
    "Administrators" : "Yöneticiler",
    "People you shared with" : "Verilerinizi paylaştığınız kişiler",
    "Privacy policy" : "Kişisel gizliliğin korunması ilkesi",
    "Read the privacy policy." : "Kişisel verilerinizin korunması ilkesini gözden geçirin.",
    "Encryption" : "Şifreleme"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/tr.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Gizlilik",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Gizlilik merkezinden verilerinizin nerede depolandığını ve yöneticiler ya da varsa paylaştığınız kişiler gibi verilerinize erişebilecek kişileri görebilirsiniz. ",
    "Remove external admin" : "Dış yöneticiyi sil",
    "Add external admin" : "Dış yönetici ekle",
    "Name of external admin" : "Dış yönetici adı",
    "This server is using full-disk-encryption." : "Bu sunucu tam disk şifrelemesi ile korunuyor.",
    "Your files are not protected by encryption." : "Dosyalarınız şifreleme ile korunmuyor.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Dosyalarınız {linkopen}sunucu tarafı şifrelemesi ↗{linkclose} ile korunuyor.",
    "This server is protected with full-disk-encryption." : "Bu sunucu tam disk şifrelemesi ile korunuyor.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Dosyalarınız {linkopen}sunucu tarafı şifrelemesi ↗{linkclose} ile korunuyor. Ek olarak bu sunucu tam disk şifrelemesi ile korunuyor.",
    "Your data is located in: " : "Verileriniz şurada tutuluyor:",
    "The admin hasn't selected the location of the server yet." : "Yönetici henüz sunucunun konumunu seçmemiş.",
    "Change data location" : "Veri konumunu değiştir",
    "Please select a region" : "Lütfen bir bölge seçin",
    "You don't have any shares with individual users." : "Diğer kullanıcılar ile herhangi bir şey paylaşmıyorsunuz.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Birleşik Arap Emirlikleri",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua ve Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Arnavutluk",
    "Armenia" : "Ermenistan",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Arjantin",
    "American Samoa" : "Amerikan Samoası",
    "Austria" : "Avusturya",
    "Australia" : "Avustralya",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Adaları",
    "Azerbaijan" : "Azerbaycan",
    "Bosnia and Herzegovina" : "Bosna ve Hersek",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeş",
    "Belgium" : "Belçika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaristan",
    "Bahrain" : "Bahreyn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivya",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius ve Saba",
    "Brazil" : "Brezilya",
    "Bahamas" : "Bahamalar",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Bouvet Adası",
    "Botswana" : "Botswana",
    "Belarus" : "Beyaz Rusya",
    "Belize" : "Beliz",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos (Keyling) Adaları",
    "Democratic Republic of the Congo" : "Kongo Demokratik Cumhuriyeti",
    "Central African Republic" : "Orta Afrika Cumhuriyeti",
    "Congo" : "Kongo",
    "Switzerland" : "İsviçre",
    "Cote d'Ivoire" : "Fildişi Sahili",
    "Cook Islands" : "Cook Adaları",
    "Chile" : "Şili",
    "Cameroon" : "Kamerun",
    "China" : "Çin",
    "Colombia" : "Kolombiya",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Küba",
    "Cabo Verde" : "Yeşil Burun Adaları",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmas Adası",
    "Cyprus" : "Kıbrıs",
    "Czech" : "Çekya",
    "Germany" : "Almanya",
    "Djibouti" : "Cibuti",
    "Denmark" : "Danimarka",
    "Dominican Republic" : "Dominik Cumhuriyeti",
    "Algeria" : "Cezayir",
    "Ecuador" : "Ekvator",
    "Estonia" : "Estonya",
    "Egypt" : "Mısır",
    "West Sahara" : "Batı Sahra",
    "Eritrea" : "Eritre",
    "Spain" : "İspanya",
    "Ethiopia" : "Etiyopya",
    "Finland" : "Finlandiya",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falkland Adaları",
    "Micronesia" : "Mikronezya",
    "Faroe Islands" : "Faroe Adaları",
    "France" : "Fransa",
    "Gabon" : "Gabon",
    "United Kingdom" : "Birleşik Kırallık",
    "Grenada" : "Grenada",
    "Georgia" : "Gürcistan",
    "French Guiana" : "Fransız Guyanası",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Gine",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvator Ginesi",
    "Greece" : "Yunanistan",
    "South Georgia and the South Sandwich Islands" : "Güney Georgia ve Güney Sandwich Adaları",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Gine-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Adası ve McDonald Adaları",
    "Croatia" : "Hırvatistan",
    "Haiti" : "Haiti",
    "Hungary" : "Macaristan",
    "Indonesia" : "Endonezya",
    "Ireland" : "İrlanda",
    "Israel" : "İsrail",
    "Isle of Man" : "Man Adası",
    "India" : "Hindistan",
    "British Indian Ocean Territory" : "Britanya Hint Okyanusu Toprakları",
    "Iraq" : "Irak",
    "Iran" : "İran",
    "Iceland" : "İzlanda",
    "Italy" : "İtalya",
    "Jamaica" : "Jamaika",
    "Jordan" : "Ürdün",
    "Japan" : "Japonya",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kırgızistan",
    "Cambodia" : "Kamboçya",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "Saint Kitts ve Nevis",
    "North Korea" : "Kuzey Kore",
    "South Korea" : "Güney Kore",
    "Kuwait" : "Kuveyt",
    "Cayman Islands" : "Cayman Adaları",
    "Kazakhstan" : "Kazakistan",
    "Laos" : "Laos",
    "Lebanon" : "Lübnan",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Lihtenştayn",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberya",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litvanya",
    "Luxembourg" : "Lüksemburg",
    "Latvia" : "Letonya",
    "Libya" : "Libra",
    "Morocco" : "Fas",
    "Monaco" : "Monako",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall Adaları",
    "Macedonia" : "Makedonya",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Moğolistan",
    "Macao" : "Makau",
    "Northern Mariana Islands" : "Kuzey Mariana Adaları",
    "Mauritania" : "Moritanya",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldivler",
    "Malawi" : "Malawi",
    "Mexico" : "Meksika",
    "Malaysia" : "Malezya",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibya",
    "New Caledonia" : "Yeni Kaledonya",
    "Niger" : "Nijer",
    "Norfolk Island" : "Norfolk Adası",
    "Nigeria" : "Nijerya",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollanda",
    "Norway" : "Norveç",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Yeni Zelanda",
    "Oman" : "Umman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransız Polinezyası",
    "Papua New Guinea" : "Papua Yeni Gine",
    "Philippines" : "Filipinler",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonya",
    "Saint Pierre and Miquelon" : "Saint Pierre ve Miquelon",
    "Pitcairn" : "Pitcairn Adaları",
    "Puerto Rico" : "Porto Riko",
    "Palestine" : "Filistin",
    "Portugal" : "Portekiz",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Romanya",
    "Serbia" : "Sırbistan",
    "Russia" : "Rusya",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Suudi Arabistan",
    "Solomon Islands" : "Solomon Adaları",
    "Seychelles" : "Seyşeller",
    "Sudan" : "Sudan",
    "Sweden" : "İsveç",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension ve Tristan da Cunha",
    "Slovenia" : "Slovenya",
    "Svalbard and Jan Mayen" : "Svalbard ve Jan Mayen",
    "Slovakia" : "Slovakya",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somali",
    "Suriname" : "Surinam",
    "South Sudan" : "Güney Sudan",
    "Sao Tome and Principe" : "Sao Tome ve Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Suriye",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Turks ve Caicos Adaları",
    "Chad" : "Çad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarktika Bölgesi",
    "Togo" : "Togo",
    "Thailand" : "Tayland",
    "Tajikistan" : "Tacikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Türkmenistan",
    "Tunisia" : "Tunus",
    "Tonga" : "Tonga",
    "Turkey" : "Türkiye",
    "Trinidad and Tobago" : "Trinidad ve Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tayvan",
    "Tanzania" : "Tanzanya",
    "Ukraine" : "Ukrayna",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Birleşik Devletler Küçük Dış Adaları",
    "United States" : "Birleşik Devletler",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Özbekistan",
    "Holy See" : "Vatikan",
    "Saint Vincent and the Grenadines" : "Saint Vincent ve Grenadinler",
    "Venezuela" : "Venezüela",
    "Virgin Islands (British)" : "Virgin Adaları (Britanya)",
    "Virgin Islands (U.S.)" : "Virgin Adaları (Birleşik Devletler)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis ve Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Güney Afrika",
    "Zambia" : "Zambiya",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Nextcloud hesabınız",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Verileriniz sizin kim olduğunuzu gösterir ve kolayca kötüye kullanılabilir. Nextcloud olarak verilerinize ne olacağına karar verme hakkınız olduğuna inanıyoruz. Nextcloud, Kullanıcı Verileri Manifestosu'nda belirtildiği şekilde haklarınızı korur!",
    "User Data Manifesto 2.0" : "Kullanıcı Verileri Manifestosu 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "İnternet çağında kişilerin kendi verilerini kontrol etmesi için temel hak tanımları",
    "Control" : "Kontrol",
    "over user data access" : "kullanıcının verilerine erişebilmesi",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Bir kullanıcı tarafından açıkça ve isteyerek yüklenen veriler, tam olarak kullanıcının kontrolü altında olmalıdır. Kullanıcılar, verilerine doğrudan kimin erişebileceğine ve bu erişim için hangi izin ve lisansların kullanılacağına karar verebilmelidir.",
    "Knowledge" : "Bilgi",
    "of how the data is stored" : "verilerin nasıl saklandığını bilme",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Veriler belirli bir hizmet sağlayıcıya yüklendiğinde, kullanıcılara bu hizmet sağlayıcısının verileri nerede ve ne kadar süreyle sakladığı, çalıştığı bölge ve bu bölgede geçerli olan yasalar hakkında bilgi verilmelidir.",
    "Freedom" : "Özgürlük",
    "to choose a platform" : "istediğiniz platformu seçebilme",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Kullanıcılar, herhangi bir hizmet sağlayıcı engellemesine maruz kalmadan, istedikleri zaman verilerini alabilmelidir. Bunu garanti etmek için biçim ve yönergeler hakkında açık standartlar bulunmalıdır.",
    "Learn more ↗" : "Ayrıntılı bilgi alın ↗",
    "Where is your data?" : "Verileriniz nerede tutuluyor?",
    "Who has access to your data?" : "Verilerinize kimler erişebiliyor?",
    "Administrators" : "Yöneticiler",
    "People you shared with" : "Verilerinizi paylaştığınız kişiler",
    "Privacy policy" : "Kişisel gizliliğin korunması ilkesi",
    "Read the privacy policy." : "Kişisel verilerinizin korunması ilkesini gözden geçirin.",
    "Encryption" : "Şifreleme"
},
"nplurals=2; plural=(n > 1);");
